@@ -1,7 +1,7 @@
 package Wubot::Plugin::OsxActiveApp;
 use Moose;
 
-our $VERSION = '0.2.004'; # VERSION
+our $VERSION = '0.2.5'; # VERSION
 
 use Wubot::Logger;
 
@@ -50,11 +50,24 @@ Wubot::Plugin::OsxActiveApp - monitor current active application in OS X
 
 =head1 VERSION
 
-version 0.2.004
+version 0.2.5
+
+=head1 SYNOPSIS
+
+  ~/wubot/config/plugins/OsxActiveApp/navi.yaml
+
+  ---
+  enable: 1
+
 
 =head1 DESCRIPTION
 
-TODO: More to come...
+Runs a little python command-line script (see the source) to determine
+which application is currently active in OS X.
+
+Sends a message containing:
+
+  application: {appname}
 
 
 =head1 SUBROUTINES/METHODS
